@@ -5,7 +5,7 @@ use warnings;
 use base 'Module::Build';
 
 use lib "inc";
-use My::Utility qw(find_SDL_dir find_file sed_inplace get_dlext);
+use My::Utility qw(find_SDL2_dir find_file sed_inplace get_dlext);
 use File::Spec::Functions qw(catdir catfile splitpath catpath rel2abs abs2rel);
 use File::Path qw(make_path remove_tree);
 use File::Copy qw(cp);
@@ -16,6 +16,7 @@ use Archive::Extract;
 use Digest::SHA qw(sha1_hex);
 use Text::Patch;
 use Config;
+use IPC::Run3;
 
 $SIG{__WARN__} = sub {
 	my $thing =  join('', @_);
@@ -39,13 +40,12 @@ sub ACTION_build {
   $self->SUPER::ACTION_build;
 }
 
-
 sub ACTION_install
 {
  my $self = shift;
  my $sharedir = '';
 
- $sharedir = eval {File::ShareDir::dist_dir('Alien-SDL')} || '';
+ $sharedir = eval {File::ShareDir::dist_dir('Alien-SDL2')} || '';
 
  if ( -d $sharedir )
  {
@@ -71,13 +71,13 @@ sub ACTION_code {
     my $patches      = 'patches';
     # we are deriving the subdir name from $bp->{title} as we want to
     # prevent troubles when user reinstalls the same version of
-    # Alien::SDL with different build options
+    # Alien::SDL2 with different build options
     my $share_subdir = $self->{properties}->{dist_version} . '_' . substr(sha1_hex($bp->{title}), 0, 8);
     my $build_out    = catfile('sharedir', $share_subdir);
     my $build_src    = 'build_src';
     $self->add_to_cleanup($build_src, $build_out);
 
-    # save some data into future Alien::SDL::ConfigData
+    # save some data into future Alien::SDL2::ConfigData
     $self->config_data('build_prefix', $build_out);
     $self->config_data('build_params', $bp);
     $self->config_data('build_cc', $Config{cc});
@@ -105,7 +105,21 @@ sub ACTION_code {
       $self->set_config_data($build_out);
       $self->set_ld_config($build_out);
     }
-    elsif($bp->{buildtype} eq 'build_from_sources' ) {
+    elsif ( $bp->{buildtype} eq 'build_from_sources' ) {
+
+        my $m = '';
+        if ( $self->notes('travis') && $self->notes('travis') == 1 ) {
+            # always select option '1'
+            $m = 1;
+        }
+        else {
+            $m = $self->prompt(
+"\nDo you want to see all messages during configure/make (y/n)?",
+                'n'
+            );
+        }
+
+      $self->notes('build_msgs', lc($m) eq 'y' ? 1 : 0);
       # all the following functions die on error, no need to test ret values
       $self->fetch_sources($download);
       $self->extract_sources($download, $patches, $build_src);
@@ -185,12 +199,9 @@ sub extract_binaries {
   my $ae = Archive::Extract->new( archive => $archive );
   die "###ERROR###: Cannot extract $archive ", $ae->error unless $ae->extract(to => $build_out);
 
-  # fix hardcoded prefix path in bin/sdl-config
-  my ($version, $prefix, $incdir, $libdir) = find_SDL_dir(rel2abs($build_out));
-  sed_inplace("$prefix/bin/sdl-config", 's/^prefix=.*/prefix=\''.quotemeta($prefix).'\'/');
-  if( $^O eq 'MSWin32' && $My::Utility::cc eq 'cl' ) {
-    cp( catfile('patches', 'SDL_config_win32.h'), catfile($incdir, 'SDL', 'SDL_config.h') );
-  }
+  # fix hardcoded prefix path in bin/sdl2-config
+  my ($version, $prefix, $incdir, $libdir) = find_SDL2_dir(rel2abs($build_out));
+  sed_inplace("$prefix/bin/sdl2-config", 's/^prefix=.*/prefix=\''.quotemeta($prefix).'\'/');
 }
 
 sub extract_sources {
@@ -205,28 +216,7 @@ sub extract_sources {
       print "Extracting $pack->{pack}...\n";
       my $ae = Archive::Extract->new( archive => $archive );
       die "###ERROR###: cannot extract $pack ", $ae->error unless $ae->extract(to => $build_src);
-      foreach my $i (@{$pack->{patches}}) {
-        chdir $srcdir;
-        my $patch_file = File::Spec->abs2rel( catfile($patches, $i), $srcdir );
-        print "Applying patch '$i'\n";
-        foreach my $k ($self->patch_get_affected_files($patch_file)) {
-          # doing the same like -p1 for 'patch'
-          $k =~ s/^[^\/]*\/(.*)$/$1/;
-          open(SRC, $k) or die "###ERROR### Cannot open file: '$k'\n";
-          my @src = <SRC>;
-          close(SRC);
-          open(DIFF, $patch_file) or die "###ERROR### Cannot open file: '$patch_file'\n";
-          my @diff = <DIFF>;
-          close(DIFF);
-          foreach(@src)  { $_=~ s/[\r\n]+$//; }
-          foreach(@diff) { $_=~ s/[\r\n]+$//; }
-          my $out = Text::Patch::patch( join("\n", @src) . "\n", join("\n", @diff) . "\n", { STYLE => "Unified" } );
-          open(OUT, ">$k") or die "###ERROR### Cannot open file for writing: '$k'\n";
-          print(OUT $out);
-          close(OUT);
-        }
-        chdir $self->base_dir();
-      }
+      $self->apply_patch($srcdir, "$patches/$_") for (@{$pack->{patches}});
     }
   }
   return 1;
@@ -235,9 +225,9 @@ sub extract_sources {
 sub set_config_data {
   my( $self, $build_out ) = @_;
 
-  # try to find SDL root dir
-  my ($version, $prefix, $incdir, $libdir) = find_SDL_dir(rel2abs($build_out));
-  die "###ERROR### Cannot find SDL directory in 'sharedir'" unless $version;
+  # try to find SDL2 root dir
+  my ($version, $prefix, $incdir, $libdir) = find_SDL2_dir(rel2abs($build_out));
+  die "###ERROR### Cannot find SDL2 directory in 'sharedir'" unless $version;
   $self->config_data('share_subdir', abs2rel($prefix, rel2abs('sharedir')));
 
   # set defaults
@@ -249,14 +239,14 @@ sub set_config_data {
   # defaults
   $cfg->{version}        = $version;
   $cfg->{prefix}         = '@PrEfIx@';
-  $cfg->{libs}           = $L . $self->get_path('@PrEfIx@/lib') . ' -lSDLmain -lSDL';
-  $cfg->{cflags}         = '-I' . $self->get_path('@PrEfIx@/include/SDL') . ' -D_GNU_SOURCE=1 -Dmain=SDL_main';
+  $cfg->{libs}           = $L . $self->get_path('@PrEfIx@/lib') . ' -lSDL2main -lSDL2';
+  $cfg->{cflags}         = '-I' . $self->get_path('@PrEfIx@/include/SDL2') . ' -D_GNU_SOURCE=1 -Dmain=SDL2_main';
   $cfg->{ld_shared_libs} = [ ];
 
-  # overwrite values available via sdl-config
+  # overwrite values available via sdl2-config
   my $bp      = $self->config_data('build_prefix') || $prefix;
   my $devnull = File::Spec->devnull();
-  my $script  = $self->escape_path( rel2abs("$prefix/bin/sdl-config") );
+  my $script  = $self->escape_path( rel2abs("$prefix/bin/sdl2-config") );
   foreach my $p (qw(version prefix libs cflags)) {
     my $o=`$script --$p 2>$devnull`;
     if ($o) {
@@ -276,7 +266,7 @@ sub set_config_data {
 
 sub set_ld_config {
   my( $self, $build_out ) = @_;
-  my ($version, $prefix, $incdir, $libdir) = find_SDL_dir(rel2abs($build_out));
+  my ($version, $prefix, $incdir, $libdir) = find_SDL2_dir(rel2abs($build_out));
   my $cfg   = $self->config_data('config') || {};
   my $dlext = get_dlext();
   # find ld_shared_libs and create symlinks if necessary
@@ -311,13 +301,13 @@ sub set_ld_config {
     elsif ($f =~ /^(lib)?(intl|z|tiff|jpeg|png|ogg|vorbis|vorbisfile|freetype|FLAC|mikmod)[^a-zA-Z]/) {
       $shlib_map{$2} = $full unless $shlib_map{$2};
     }
-    elsif ($f =~ /^(lib)?(SDL_[a-zA-Z]{2,8})[^a-zA-Z0-9]/) {
-      # sort of dark magic how to detect SDL_<something> related shlib
+    elsif ($f =~ /^(lib)?(SDL2_[a-zA-Z]{2,8})[^a-zA-Z0-9]/) {
+      # sort of dark magic how to detect SDL2_<something> related shlib
       $shlib_map{$2} = $full unless $shlib_map{$2};
     }
-    elsif ($f =~ /^(lib)?(SDL)/) {
-      # '*SDL*' that did not pass previous test is probably core 'SDL'
-      $shlib_map{SDL} = $full unless $shlib_map{SDL};
+    elsif ($f =~ /^(lib)?(SDL2)/) {
+      # '*SDL2*' that did not pass previous test is probably core 'SDL2'
+      $shlib_map{SDL2} = $full unless $shlib_map{SDL2};
     }
   };
 
@@ -347,7 +337,7 @@ sub can_build_binaries_from_sources {
 sub build_binaries {
   # this needs to be overriden in My::Builder::<platform>
   my ($self, $build_out, $build_src) = @_;
-  die "###ERROR### My::Builder cannot build SDL from sources, use rather My::Builder::<platform>";
+  die "###ERROR### My::Builder cannot build SDL2 from sources, use rather My::Builder::<platform>";
 }
 
 sub get_additional_cflags {
@@ -413,12 +403,102 @@ sub check_sha1sum {
   return ($_sha1sum eq $sha1sum) ? 1 : 0
 }
 
-sub patch_get_affected_files {
-  my( $self, $patch_file ) = @_;
+# pure perl implementation of patch functionality
+sub apply_patch {
+  my ($self, $dir_to_be_patched, $patch_file) = @_;
+  my ($src, $diff);
+
+  undef local $/;
   open(DAT, $patch_file) or die "###ERROR### Cannot open file: '$patch_file'\n";
-  my @affected_files = map{$_ =~ /^---\s*([\S]+)/} <DAT>;
+  $diff = <DAT>;
   close(DAT);
-  return @affected_files;
+  $diff =~ s/\r\n/\n/g; #normalise newlines
+  $diff =~ s/\ndiff /\nSpLiTmArKeRdiff /g;
+  my @patches = split('SpLiTmArKeR', $diff);
+
+  print STDERR "Applying patch file: '$patch_file'\n";
+  foreach my $p (@patches) {
+    my ($k) = $p =~ /^---\s*([\S]+)/;
+    # doing the same like -p1 for 'patch'
+    $k =~ s|\\|/|g;
+    $k =~ s|^[^/]*/(.*)$|$1|;
+    $k = catfile($dir_to_be_patched, $k);
+    print STDERR "- gonna patch '$k'\n";
+
+    if (-f $k) {
+      open(SRC, "<", $k) or die "###ERROR### Cannot open file: '$k'\n";
+      $src  = <SRC>;
+      close(SRC);
+      $src =~ s/\r\n/\n/g; #normalise newlines
+    }
+    else {
+      $src = "";
+    }
+
+    my $out = eval { Text::Patch::patch( $src, $p, { STYLE => "Unified" } ) };
+    if ($out) {
+      open(OUT, ">", $k) or die "###ERROR### Cannot open file for writing: '$k'\n";
+      print(OUT $out);
+      close(OUT);
+    }
+    else {
+      warn "###WARN### Patching '$k' failed: $@";
+    }
+  }
+}
+
+sub run_output_on_error {
+  my ($self, $limit, $cmd) = @_;
+  my $output;
+  my $c = ref($cmd) eq 'ARRAY' ? join(' ',@$cmd) : $cmd;
+  print STDERR "CMD: $c\n";
+  print STDERR "- running (stdout+stderr redirected)...\n";
+  my $rv = run3($cmd, \undef, \$output, \$output, { return_if_system_error => 1 } );
+  my $success = ($rv == 1 && $? == 0) ? 1 : 0;
+  if ($success) {
+    print STDERR "- finished successfully (output suppressed)\n";
+  }
+  else {
+    $output = substr $output, -$limit if defined $limit; # we want just last N chars
+    if (!defined($limit)) {
+      print STDERR "OUTPUT:\n", $output, "\n";
+    }
+    elsif ($limit>0) {
+      print STDERR "OUTPUT: (only last $limit chars)\n", $output, "\n";
+    }
+  }
+  return $success;
+}
+
+sub run_output_std {
+  my ($self, $cmd) = @_;
+  my $c = ref($cmd) eq 'ARRAY' ? join(' ',@$cmd) : $cmd;
+  print STDERR "CMD: $c\n";
+  my $rv = run3($cmd, undef, undef, undef, { return_if_system_error => 1 } );
+  my $success = ($rv == 1 && $? == 0) ? 1 : 0;
+  print STDERR "- finished successfully\n" if ($success);
+  return $success;
+}
+
+sub run_custom {
+  my ($self, $cmd) = @_;
+  my $rv;
+  if ($self->notes('build_msgs')) {
+    $rv = $self->run_output_std($cmd);
+  }
+  else {
+    $rv = $self->run_output_on_error(undef, $cmd);
+  }
+  #warn "###WARN### error during run_custom()" unless $rv;
+  return $rv;
+}
+
+sub run_stdout2str {
+  my ($self, $cmd) = @_;
+  my $output;
+  my $rv = run3($cmd, \undef, \$output, \undef, { return_if_system_error => 1 } );
+  $output =~ s/[\r\n]*$//;
+  return $output;
 }
 
 1;
