@@ -3,8 +3,8 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_prereqs_libs check_prereqs_tools find_SDL_dir find_file check_header
-                    sed_inplace get_dlext $inc_lib_candidates $source_packs check_perl_buildlibs);
+our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_prereqs_libs check_prereqs_tools find_SDL2_dir find_file check_header
+                    sed_inplace get_dlext $inc_lib_candidates $source_packs);
 use Config;
 use ExtUtils::CBuilder;
 use File::Spec::Functions qw(splitdir catdir splitpath catpath rel2abs);
@@ -29,74 +29,30 @@ $inc_lib_candidates->{'/usr/X11R7/include'}     = '/usr/X11R7/lib'            if
 $inc_lib_candidates->{'/usr/include/ogg'}       = '/usr/lib/x86_64-linux-gnu' if -f '/usr/lib/x86_64-linux-gnu/libogg.so';
 $inc_lib_candidates->{'/usr/include/vorbis'}    = '/usr/lib/x86_64-linux-gnu' if -f '/usr/lib/x86_64-linux-gnu/libvorbis.so';
 $inc_lib_candidates->{'/usr/include'}           = '/usr/lib64'                if -e '/usr/lib64' && $Config{'myarchname'} =~ /64/;
-$inc_lib_candidates->{$ENV{SDL_INC}}            = $ENV{SDL_LIB}               if exists $ENV{SDL_LIB} && exists $ENV{SDL_INC};
+$inc_lib_candidates->{'/usr/include'}           = ['/usr/lib64', '/usr/lib']  if -e '/usr/lib64' && -e '/usr/lib' && $Config{'myarchname'} =~ /64/;
+
+$inc_lib_candidates->{$ENV{SDL2_INC}}           = $ENV{SDL2_LIB}              if exists $ENV{SDL2_LIB} && exists $ENV{SDL2_INC};
 
 #### packs with prebuilt binaries
-# - all regexps has to match: arch_re ~ $Config{archname}, cc_re ~ $Config{cc}, os_re ~ $^O
-# - the order matters, we offer binaries to user in the same order (1st = preffered)
+# the order matters, we offer binaries to user in the same order (1st = preffered)
 my $prebuilt_binaries = [
     {
-      title    => "Binaries Win/32bit SDL-1.2.14 (extended, 20100704) RECOMMENDED\n" .
-                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
+      title    => "Binaries Win/32bit SDL2 (20130305) RECOMMENDED\n" .
+                  "\t(gfx, image, mixer, net, smpeg, ttf)",
       url      => [
-        'http://strawberryperl.com/package/kmx/sdl/Win32_SDL-1.2.14-extended-bin_20100704.zip',
-        'http://froggs.de/libsdl/Win32_SDL-1.2.14-extended-bin_20100704.zip',
+        'http://strawberryperl.com/package/kmx/sdl/32bit_SDL2_20130305.zip',
       ],
-      sha1sum  => '98409ddeb649024a9cc1ab8ccb2ca7e8fe804fd8',
-      arch_re  => qr/^MSWin32-x86-multi-thread(-64int)?$/,
-      os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc/,
+      sha1sum  => 'e77e5f04339d60871e9b79f66ac1bca4996648a7',
+      match    => sub { $Config{archname} =~ /^MSWin32-x86-/ && $Config{cc} =~ /gcc/ },
     },
     {
-      title    => "Binaries Win/32bit SDL-1.2.14 (extended, 20111205)\n" .
-                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
+      title    => "Binaries Win/64bit SDL2 (20130305) RECOMMENDED\n" .
+                  "\t(gfx, image, mixer, net, smpeg, ttf)",
       url      => [
-        'http://strawberryperl.com/package/kmx/sdl/Win32_SDL-1.2.14-extended-bin_20111205.zip',
-        'http://froggs.de/libsdl/Win32_SDL-1.2.14-extended-bin_20111205.zip',
+        'http://strawberryperl.com/package/kmx/sdl/64bit_SDL2_20130305.zip',
       ],
-      sha1sum  => '553b7e21bb650d047ec9f2a5f650c67d76430e61',
-      arch_re  => qr/^MSWin32-x86-multi-thread(-64int)?$/,
-      os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc/,
-    },
-    {
-      title    => "Binaries Win/64bit SDL-1.2.14 (extended, 20100824)\n" .
-                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)\n" .
-                  "\tBEWARE: binaries are using old ABI - will fail with the latest gcc\n" .
-                  "\tBEWARE: this is intended just for old strawberryperl 5.12.x/64bit",
-      url      => [
-        'http://strawberryperl.com/package/kmx/sdl/Win64_SDL-1.2.14-extended-bin_20100824.zip',
-        'http://froggs.de/libsdl/Win64_SDL-1.2.14-extended-bin_20100824.zip',
-      ],
-      sha1sum  => 'ccffb7218bcb17544ab00c8a1ae383422fe9586d',
-      arch_re  => qr/^MSWin32-x64-multi-thread$/,
-      os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc/,
-      gccversion_re => qr/^4\.4\.3$/, #specific to the old gcc compiler used in 64bit strawberryperl 5.12.x
-    },
-    {
-      title    => "Binaries Win/64bit SDL-1.2.14 (extended, 20111205) RECOMMENDED\n" .
-                  "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
-      url      => [
-        'http://strawberryperl.com/package/kmx/sdl/Win64_SDL-1.2.14-extended-bin_20111205.zip',
-        'http://froggs.de/libsdl/Win64_SDL-1.2.14-extended-bin_20111205.zip',
-      ],
-      sha1sum  => '35f3b496ca443a9d14eff77e9e26acfa813afafd',
-      arch_re  => qr/^MSWin32-x64-multi-thread$/,
-      os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc/,
-      gccversion_re => qr/^4\.(4\.[5-9]|[5-9]\.[0-9])$/,
-    },
-    {
-      title    => "Binaries Win/32bit SDL-1.2.15 (20120612)\n" .
-                  "\t(gfx, image, mixer, smpeg, ttf)",
-      url      => [
-        'http://froggs.de/libsdl/Win32_SDL-1.2.15-20120612.zip',
-      ],
-      sha1sum  => '22c531c1d0cc5a363c05045760870b2f45e9d0da',
-      arch_re  => qr/^MSWin32/,
-      os_re    => qr/^MSWin32$/,
-      cc_re    => qr/cl/,
+      sha1sum  => 'f4d9b5e933029571ebbc1e323f504300da7988bc',
+      match    => sub { $Config{archname} =~ /^MSWin32-x64-/ && $Config{cc} =~ /gcc/ },
     },
  ];
 
@@ -107,129 +63,94 @@ our $source_packs = [
     members => [
       {
         pack => 'z',
-        version => '1.2.5',
-        dirname => 'zlib-1.2.5',
+        version => '1.2.8',
+        dirname => 'zlib-1.2.8',
         url => [
-          'http://froggs.de/libz/zlib-1.2.5.tar.gz',
+          'http://zlib.net/zlib-1.2.8.tar.gz'
         ],
-        sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
-        patches => [
-          'zlib-1.2.5-bsd-ldconfig.patch',
-        ],
-        prereqs => {
-          libs => [ ]
-        }
+        sha1sum  => 'a4d316c404ff54ca545ea71a27af7dbc29817088',
+        patches => [],
+        prereq_libs => [],
       },
       {
         pack => 'jpeg',
-        version => '8b',
-        dirname => 'jpeg-8b',
+        version => '9',
+        dirname => 'jpeg-9',
         url => [
-          'http://www.ijg.org/files/jpegsrc.v8b.tar.gz',
-          'http://froggs.de/libjpeg/jpegsrc.v8b.tar.gz',
+          'http://www.ijg.org/files/jpegsrc.v9.tar.gz'
         ],
-        sha1sum  => '15dc1939ea1a5b9d09baea11cceb13ca59e4f9df',
-        patches => [
-          'jpeg-8a_cygwin.patch',
-        ],
-        prereqs => {
-          libs => [ ]
-        }
+        sha1sum  => '724987e7690ca3d74d6ab7c1f1b6854e88ca204b',
+        patches => [],
+        prereq_libs => [],
       },
       {
         pack => 'tiff',
-        version => '3.9.1',
-        dirname => 'tiff-3.9.1',
+        version => '4.0.3',
+        dirname => 'tiff-4.0.3',
         url => [
-          'http://froggs.de/libtiff/tiff-3.9.1.tar.gz',
-          'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+          'ftp://ftp.remotesensing.org/pub/libtiff/tiff-4.0.3.tar.gz',
         ],
-        sha1sum  => '675ad1977023a89201b80cd5cd4abadea7ba0897',
-        patches => [ ],
-        prereqs => {
-          libs => [ ]
-        }
+        sha1sum  => '652e97b78f1444237a82cbcfe014310e776eb6f0',
+        patches => ['libtiff.4.0.3.tiffio.h.patch'],
+        prereq_libs => [],
       },
       {
         pack => 'png',
-        version => '1.4.1',
-        dirname => 'libpng-1.4.1',
+        version => '1.6.3',
+        dirname => 'libpng-1.6.3',
         url => [
-          'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
+          'http://downloads.sourceforge.net/libpng/libpng-1.6.3.tar.gz',
         ],
-        sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
-        prereqs => {
-          libs => [
-            'z',
-          ]
-        }
+        sha1sum  => 'b8b7b911909c09d71324536aaa7750104d170c77',
+        patches => ['libpng-1.6.3-hack.patch'],
+        prereq_libs => ['z'],
       },
       {
         pack => 'freetype',
-        version => '2.3.12',
-        dirname => 'freetype-2.3.12',
+        version => '2.5.0.1',
+        dirname => 'freetype-2.5.0.1',
         url => [
-          'http://mirror.lihnidos.org/GNU/savannah/freetype/freetype-2.3.12.tar.gz',
-          'http://froggs.de/libfreetype/freetype-2.3.12.tar.gz',
+          'http://www.mirrorservice.org/sites/download.savannah.gnu.org/releases/freetype/freetype-2.5.0.1.tar.gz',
         ],
-        sha1sum  => '0082ec5e99fec5a1c6d89b321a7e2f201542e4b3',
-        prereqs => {
-          libs => [ ]
-        }
+        sha1sum  => '2d539b375688466a8e7dcc4260ab21003faab08c',
+        patches => [],
+        prereq_libs => ['SDL2', 'freetype'],
       },
       {
-        pack => 'SDL',
-        version => '1.2.15',
-        dirname => 'SDL-1.2',
+        pack => 'SDL2',
+        version => '2.0.0',
+        dirname => 'SDL2-2.0.0',
         url => [
-          'http://froggs.de/libsdl/SDL-1.2-2b923729fd01.tar.gz',
+          'http://www.libsdl.org/release/SDL2-2.0.0.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/SDL2-2.0.0.tar.gz',
         ],
-        sha1sum  => 'ec9841377403e8d1bcfd76626434be64d11f59f0',
-        patches => [
-          'test1.patch',
-          'SDL-1.2-openbsd-rldflags.patch',
-          'libsdl-1.2.15-const-xdata32.1.patch',
-          'libsdl-1.2.15-const-xdata32.2.patch',
-          'libsdl-1.2.15-const-xdata32.3.patch',
-          'libsdl-1.2.15-const-xdata32.4.patch',
-          'SDL-1.2.15-PIC-in-CFLAGS.patch',
-          'SDL-1.2.15-Makefile.in-OBJECTS.patch',
-        ],
-        prereqs => {
-          libs => [
-            'pthread',
-          ]
-        },
+        sha1sum  => 'a907eb5203abad6649c1eae0120d96c0a1931350',
+        patches => [],
+        prereq_libs => ['pthread'],
       },
       {
-        pack => 'SDL_image',
-        version => '1.2.11',
-        dirname => 'SDL_image-1.2.11',
+        pack => 'SDL2_image',
+        version => '2.0.0',
+        dirname => 'SDL2_image-2.0.0',
         url => [
-          'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.11.tar.gz',
-          'http://froggs.de/libsdl/SDL_image-1.2.11.tar.gz',
+          'http://www.libsdl.org/projects/SDL_image/release/SDL2_image-2.0.0.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/SDL2_image-2.0.0.tar.gz',
         ],
-        sha1sum  => 'dd384ff87848595fcc0691833431ec5029f973c7',
-        patches => [
-          'SDL_image-1.2.11-CGFloat.patch',
-          'SDL_image-1.2.11-libpng-flags.patch',
-        ],
-        prereqs => {
-          libs => [
-            'jpeg', 'tiff', 'png',
-          ]
-        }
+        sha1sum  => '20b1b0db9dd540d6d5e40c7da8a39c6a81248865',
+        patches => [],
+        prereq_libs => ['SDL2', 'jpeg', 'tiff', 'png'],
       },
       {
         pack => 'ogg',
-        version => '1.3.0',
-        dirname => 'libogg-1.3.0',
+        version => '1.3.1',
+        dirname => 'libogg-1.3.1',
         url => [
-          'http://downloads.xiph.org/releases/ogg/libogg-1.3.0.tar.gz',
-          'http://froggs.de/libsdl/libogg-1.3.0.tar.gz',
+          'http://downloads.xiph.org/releases/ogg/libogg-1.3.1.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/libogg-1.3.1.tar.gz',
         ],
-        sha1sum  => 'a900af21b6d7db1c7aa74eb0c39589ed9db991b8',
-        patches => [ ],
+        sha1sum  => '270685c2a3d9dc6c98372627af99868aa4b4db53',
+        patches => [],
+        prereq_libs => [],
       },
       {
         pack => 'vorbis',
@@ -237,93 +158,67 @@ our $source_packs = [
         dirname => 'libvorbis-1.3.3',
         url => [
           'http://downloads.xiph.org/releases/vorbis/libvorbis-1.3.3.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/libvorbis-1.3.3.tar.gz',
           'http://froggs.de/libsdl/libvorbis-1.3.3.tar.gz',
         ],
         sha1sum  => '8dae60349292ed76db0e490dc5ee51088a84518b',
         patches => [
           'libvorbis-1.3.3-configure.patch',
         ],
-        prereqs => {
-          libs => [ ]
-        }
+        prereq_libs => [],
       },
       {
-        pack => 'SDL_mixer',
-        version => '1.2.12',
-        dirname => 'SDL_mixer-1.2.12',
+        pack => 'SDL2_mixer',
+        version => '2.0.0',
+        dirname => 'SDL2_mixer-2.0.0',
         url => [
-          'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.12.tar.gz',
-          'http://froggs.de/libsdl/SDL_mixer-1.2.12.tar.gz',
+          'http://www.libsdl.org/projects/SDL_mixer/release/SDL2_mixer-2.0.0.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/SDL2_mixer-2.0.0.tar.gz',
         ],
-        sha1sum  => 'a20fa96470ad9e1052f1957b77ffa68fb090b384',
-        patches => [
-          'SDL_mixer-1.2.12-native-midi-win32.patch',
-        ],
-        prereqs => {
-          libs => [
-            'ogg', 'vorbis',
-          ]
-        },
+        sha1sum  => '9ed975587f09a1776ba9776dcc74a58e695aba6e',
+        patches => [],
+        prereq_libs => ['SDL2', 'ogg', 'vorbis', 'smpeg'],
       },
       {
-        pack => 'SDL_ttf',
-        version => '2.0.11',
-        dirname => 'SDL_ttf-2.0.11',
+        pack => 'SDL2_ttf',
+        version => '2.0.12',
+        dirname => 'SDL2_ttf-2.0.12',
         url => [
-          'http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.11.tar.gz',
-          'http://froggs.de/libsdl/SDL_ttf-2.0.11.tar.gz',
+          'http://www.libsdl.org/projects/SDL_ttf/release/SDL2_ttf-2.0.12.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/SDL2_ttf-2.0.12.tar.gz',
         ],
-        sha1sum  => '0ccf7c70e26b7801d83f4847766e09f09db15cc6',
-        patches => [ ],
-        prereqs => {
-          libs => [
-            'freetype', # SDL_ttf
-          ]
-        },
+        sha1sum  => '542865c604fe92d2f26000428ef733381caa0e8e',
+        patches => [],
+        prereq_libs => ['freetype'],
       },
       {
-        pack => 'SDL_gfx',
-        version => '2.0.25',
-        dirname => 'SDL_gfx-2.0.25',
+        pack => 'SDL2_gfx',
+        version => '20130301-hg',
+        dirname => 'SDL2_gfx-svn20130301',
         url => [
-          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.25.tar.gz',
-          'http://froggs.de/libsdl/SDL_gfx-2.0.25.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/SDL2_gfx-svn20130301.tar.gz',
         ],
-        sha1sum  => '20a89d0b71b7b790b830c70f17ed2c44100bc0f4',
-        patches => [ ],
-        prereqs => {
-          libs => [ ]
-        }
+        sha1sum  => '3ba18531d34f442ba9f4f6d84feb353dfb9c8130',
+        patches => [],
+        prereq_libs => ['SDL2'], 
       },
       {
-        pack => 'SDL_Pango',
-        version => '1.2',
-        dirname => 'SDL_Pango-0.1.2',
+        pack => 'smpeg',
+        version => '20130301-svn',
+        dirname => 'libsmpeg-svn20130301',
         url => [
-          'http://downloads.sourceforge.net/sdlpango/SDL_Pango-0.1.2.tar.gz',
-          'http://froggs.de/libsdl/SDL_Pango-0.1.2.tar.gz',
+          'http://strawberryperl.com/package/kmx/sdl/src/libsmpeg-svn20130301.tar.gz',
         ],
-        sha1sum  => 'c30f2941d476d9362850a150d29cb4a93730af68',
-        patches => [
-          'SDL_Pango-0.1.2-API-adds.1.patch',
-          'SDL_Pango-0.1.2-API-adds.2.patch',
-          'SDL_Pango-0.1.2-config-tools.1.patch',
-          'SDL_Pango-0.1.2-config-tools.2.patch',
-          'SDL_Pango-0.1.2-config-tools.3.patch',
-          'SDL_Pango-0.1.2-include-ft2build.h.patch',
-        ],
-        prereqs => {
-          libs => [
-            'pangoft2', 'pango', 'gobject', 'gmodule', 'glib', 'fontconfig', 'freetype', 'expat', # SDL_Pango
-          ]
-        }
+        sha1sum  => 'bba9f1f5313bf02bd4e5ee9f7b7d7459086647a1',
+        patches => [],
+        prereq_libs => ['SDL'],
       },
     ],
   },
 ];
 
 sub check_config_script {
-  my $script = shift || 'sdl-config';
+  my $script = shift || 'sdl2-config';
   print "checking for config script... ";
   my $devnull = File::Spec->devnull();
   my $version = `$script --version 2>$devnull`;
@@ -338,28 +233,40 @@ sub check_config_script {
   }
   $version =~ s/[\r\n]+$//;
   $prefix  =~ s/[\r\n]+$//;
+  $prefix = rel2abs($prefix);
   print "yes, $script\n";
   #returning HASHREF
   return {
-    title     => "Already installed SDL ver=$version path=$prefix",
+    title     => "Already installed SDL2 ver=$version path=$prefix",
     buildtype => 'use_config_script',
     script    => $script,
     prefix    => $prefix,
   };
 }
 
+sub find_dll_lib_inc {
+ my ($inc, $ld, $lib, $dlext, $header ) = @_;
+    my $found_dll          = '';
+    my $found_lib          = '';
+    my $found_inc          = '';
+     
+    ($found_dll) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|so|dll)$/);
+      $found_dll   = $1 if $found_dll && $found_dll =~/^(.+($dlext|so|dll))/ && -e $1;
+
+    ($found_inc) = find_file($inc,  qr/[\/\\]\Q$header\E[\-\d\.]*\.h$/);
+    ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|a|dll.a)$/);
+
+  return ( $found_dll, $found_lib, $found_inc );
+}
+
 sub check_prebuilt_binaries
 {
   print "checking for prebuilt binaries... ";
-#  print "(os=$^O cc=$cc archname=$Config{archname})\n";
   my @good = ();
   foreach my $b (@{$prebuilt_binaries}) {
-    if ( ($^O =~ $b->{os_re}) &&
-         ($Config{archname} =~ $b->{arch_re}) &&
-         ($cc =~ $b->{cc_re}) &&
-         (!defined $b->{gccversion_re} || $Config{gccversion} =~ $b->{gccversion_re})
-        ) {
+    if ($b->{match} && &{$b->{match}}) {
       $b->{buildtype} = 'use_prebuilt_binaries';
+      delete $b->{match}; #avoid later warnings
       push @good, $b;
     }
   }
@@ -383,19 +290,26 @@ sub check_prereqs_libs {
       'z'       => 'zlib',
       'jpeg'    => 'jpeglib',
       'vorbis'  => 'vorbisenc',
-      'SDL_gfx' => 'SDL_gfxPrimitives',
-      'SDL'     => 'SDL_version',
+      'SDL2_gfx' => 'SDL2_gfxPrimitives',
+      'SDL2'     => 'SDL_version',
     };
     my $header             = (defined $header_map->{$lib}) ? $header_map->{$lib} : $lib;
-
     my $dlext = get_dlext();
     foreach (keys %$inc_lib_candidates) {
-      my $ld = $inc_lib_candidates->{$_};
-      next unless -d $_ && -d $ld;
-      ($found_dll) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|so|dll)$/);
-      $found_dll   = $1 if $found_dll && $found_dll =~/^(.+($dlext|so|dll))/ && -e $1;
-      ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|a|dll.a)$/);
-      ($found_inc) = find_file($_,  qr/[\/\\]\Q$header\E[\-\d\.]*\.h$/);
+      my $inc = $_;
+      my $ld = $inc_lib_candidates->{$inc};
+      next unless -d $_ && (-d $ld || ref $ld eq 'ARRAY');
+	if( ref $ld eq 'ARRAY' ) {
+		   my $ld_size = scalar( @{ $ld } );
+		   foreach ( 0..$ld_size ) {
+			next unless (defined $ld->[$_] && -d $ld->[$_]);
+			  ($found_dll, $found_lib, $found_inc) = find_dll_lib_inc($inc, $ld->[$_], $lib, $dlext, $header );
+			last if $found_lib;
+		}
+	}
+	else {
+	  ($found_dll, $found_lib, $found_inc) = find_dll_lib_inc($inc, $ld, $lib, $dlext, $header,);
+	}
       last if $found_lib && $found_inc;
     }
 
@@ -407,6 +321,7 @@ sub check_prereqs_libs {
       print "no\n";
       $ret = 0;
     }
+  warn "###ERROR### Can't find $lib, will not compile libSDL2" if ($lib =~ 'pthread' && $ret == 0);
 
     if( scalar(@libs) == 1 ) {
       return $ret
@@ -418,31 +333,10 @@ sub check_prereqs_libs {
   return $ret;
 }
 
-sub check_perl_buildlibs {
-  my @libs    = @_;
-  my $ret     = 1;
-  my $dlext   = get_dlext();
-  my $devnull = File::Spec->devnull();
-  for my $lib (@libs) {
-    print "checking if perl is linked against $lib... ";
-    if($Config{libs}        =~ /\Q-l$lib\E\b/
-    || $Config{perllibs}    =~ /\Q-l$lib\E\b/
-    || `ldd $^X 2>$devnull` =~ /[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|so|dll)$/) {
-      print "yes\n";
-      $ret &= 1;
-    }
-    else {
-      print "no\n";
-      $ret = 0;
-    }
-  }
-  return $ret;
-}
-
 sub check_prereqs {
   my $bp  = shift;
   my $ret = 1;
-  $ret   &= check_prereqs_libs(@{$bp->{prereqs}->{libs}}) if defined $bp->{prereqs}->{libs};
+  $ret   &= check_prereqs_libs(@{$bp->{prereq_libs}}) if defined $bp->{prereq_libs};
 
   return $ret;
 }
@@ -479,7 +373,7 @@ sub find_file {
   return @files;
 }
 
-sub find_SDL_dir {
+sub find_SDL2_dir {
   my $root = shift;
   my ($version, $prefix, $incdir, $libdir);
   return unless $root;
@@ -500,12 +394,12 @@ sub find_SDL_dir {
   $v_pat =~ s/^#define[ \t]+SDL_PATCHLEVEL[ \t]+([0-9]+)[.\r\n]*$/$1/;
   return if (($v_maj eq '')||($v_min eq '')||($v_pat eq ''));
   $version = "$v_maj.$v_min.$v_pat";
-
+  
   # get prefix dir
   my ($v, $d, $f) = splitpath($found);
   my @pp = reverse splitdir($d);
   shift(@pp) if(defined($pp[0]) && $pp[0] eq '');
-  shift(@pp) if(defined($pp[0]) && $pp[0] eq 'SDL');
+  shift(@pp) if(defined($pp[0]) && $pp[0] eq 'SDL2');
   if(defined($pp[0]) && $pp[0] eq 'include') {
     shift(@pp);
     @pp = reverse @pp;
@@ -522,7 +416,7 @@ sub check_header {
   my ($cflags, @header) = @_;
   print STDERR "Testing header(s): " . join(', ', @header) . "\n";
   my $cb = ExtUtils::CBuilder->new(quiet => 1);
-  my ($fs, $src) = File::Temp::tempfile('aaXXXX', SUFFIX => '.c', UNLINK => 1);
+  my ($fs, $src) = File::Temp->tempfile( 'XXXX', SUFFIX => 'aa.c', UNLINK => 1);
   my $inc = '';
   $inc .= "#include <$_>\n" for @header;
   syswrite($fs, <<MARKER); # write test source code
